#include <Arduino.h>
#include "A4988.h"
#include <Servo.h>

//pinout node board
#define A4988_EN        6
#define A4988_STEP      5
#define A4988_DIR       4
#define SERVO_PIN       10
#define COM_RX          0
#define COM_TX          1
#define LED_POWER       2
#define LED_STATUS      3

//Stepper
//#define YAXIS_P
#define YAXIS_M
//#define XZAXIS
#define MOTOR_STEPS 48 //adjust steps if needed

//Commands
#define XP  '0' //X+
#define XM  '1' //X-
#define YP  '2' //Y+
#define YM  '3' //Y-
#define ZP  '4' //Z+
#define ZM  '5' //Z-

A4988 stepper(MOTOR_STEPS, A4988_DIR, A4988_STEP, A4988_EN);
Servo zServo;

void toggleLed(int led)
{
  digitalWrite(led,!digitalRead(led));
}

void setup() 
{
    pinMode(LED_POWER, OUTPUT);
    pinMode(LED_STATUS, OUTPUT);
    pinMode(A4988_EN, OUTPUT);
    pinMode(A4988_STEP, OUTPUT);
    pinMode(A4988_DIR, OUTPUT);
    pinMode(SERVO_PIN, OUTPUT);
    Serial.begin(9600);
    digitalWrite(LED_POWER, HIGH);
    digitalWrite(LED_STATUS, LOW);
    digitalWrite(SERVO_PIN, LOW);
    pinMode(COM_TX, INPUT); //configures tx as input so the communication bus is open and other nodes can connect
    
    stepper.begin(20, 1); //15rpm full step
    stepper.disable(); //disable stepper driver
    //stepper.move(10);

    #ifdef XZAXIS
    zServo.attach(SERVO_PIN);
    //zServo.write(120);
    #endif
}

void loop() 
{
    char cmd_read;
    if (Serial.available()) 
    {
      cmd_read = Serial.read();
      toggleLed(LED_STATUS);
      //digitalWrite(LED_STATUS, HIGH);

      #ifdef YAXIS_P
        if (cmd_read == YP) 
        {
            stepper.enable();
            stepper.move(5);
            stepper.disable();
        }
        else if (cmd_read == YM)
        {
            stepper.enable();
            stepper.move(-5);
            stepper.disable();
        }
      #endif

      
      #ifdef YAXIS_M
        //inverted Y AXIS
        if (cmd_read == YP) 
        {
            stepper.enable();
            stepper.move(-5);
            stepper.disable();
        }
        else if (cmd_read == YM)
        {
            stepper.enable();
            stepper.move(5);
            stepper.disable();
        }
      #endif

      
      #ifdef XZAXIS

        if (cmd_read == XP) 
        {
            stepper.enable();
            stepper.move(5);
            stepper.disable();
        }
        else if (cmd_read == XM)
        {
            stepper.enable();
            stepper.move(-5);
            stepper.disable();
        }
        
        if (cmd_read == ZP) 
        {
            zServo.write(90);
        }
        else if (cmd_read == ZM)
        {
            zServo.write(130);
        }
      #endif
    }
}
